@@ -1,20 +1,21 @@
+# -*- coding: utf-8 -*-
+
+from __future__ import absolute_import
+
 # set the warning format to be on a single line
 import warnings as _warnings
-from os.path import abspath as _abspath, dirname as _dirname
 from os import name as _name
+from os.path import abspath as _abspath
+from os.path import dirname as _dirname
 
-from .version import get_version
-from .core import Object, Metabolite, Gene, Reaction, Model, \
-    DictList, Species
-from . import io, flux_analysis, design
+from cobra.core import (
+    Configuration, DictList, Gene, Metabolite, Model, Object, Reaction,
+    Species)
+from cobra import flux_analysis
+from cobra import io
+from cobra.util import show_versions
 
-try:
-    from .core import ArrayBasedModel
-except ImportError:
-    None
-
-__version__ = get_version()
-del get_version
+__version__ = "0.14.1"
 
 # set the warning format to be prettier and fit on one line
 _cobra_path = _dirname(_abspath(__file__))
